#include "validation.h"

const int MAX_N = 100'000;
const std::string alphabet = "abcdefghijklmnopqrstuvwxyz";

/*
 * The output format is simple, it contains just contains a string of lowercase
 * letters on a single line. We should check that this string has at most MAX_N
 * characters, and then that it has the exact number of palindromes asked.
 */

// Count the number of palindromes in a string in O(N) using Manacher's
// Algorithms.
long long count_palindromes(std::string str) {
    long long res = 0LL;  
    
    std::string new_string;

    // Pad a string with random characters to simplify even palindromes:
    // abac -> a#b#a#c
    for (int i = 0; i + 1 < (int)str.size(); ++i) {
        new_string.push_back(str[i]);
        new_string.push_back('#');
    }
    new_string.push_back(str.back());

    std::vector<int> ext(new_string.size() + 1);

    int best_pal = 0;

    for (int i = 0; i < (int)new_string.size(); ++i) {
        // i is outside of the best palindrome
        if (best_pal + ext[best_pal] < i)
            best_pal = i;
        // we're inside the best palindrome
        else {
            // Use palindrome symmetry to find how much this palindrome
            // can be extended
            ext[i] = ext[best_pal - (i - best_pal)];

            // If our palindrome extends further than the best palindrome
            // then we must restart our current palindrome, and now this is
            // the best palindrome
            if (i + ext[i] >= best_pal + ext[best_pal]) {
                ext[i] = best_pal + ext[best_pal] - i;
                best_pal = i;
            }
        }
        
        // Extend the current best palindrome by bruteforce
        while (best_pal + ext[best_pal] + 1 < (int)new_string.size() &&
               best_pal - ext[best_pal] - 1 >= 0 &&
               new_string[best_pal - ext[best_pal] - 1] == 
                 new_string[best_pal + ext[best_pal] + 1])
            ext[best_pal]++;
    
        // We don't care about the palindromes that finish in '#'
        if (new_string[i] == '#')
            res = res + (ext[i] + 1) / 2;
        else
            res = res + 1 + ext[i] / 2;
    }
    
    return res;
}

int main(int argc, char **argv) {
    int s;

    // Set up the input and answer streams.
    std::ifstream in(argv[1]);
    in >> s;

    OutputValidator v(argc, argv);
    
    if (alphabet.size() != 26)
        v.WA("Wrong alphabet size");

    std::string str = v.read_string("answer", 1, MAX_N, alphabet);
    v.newline();

    if (count_palindromes(str) != s)
        v.WA("Wrong number of palindromes");

    return 0;
}
