#include "validation.h"

// This validator generates random points,
// calculates the correct answer for these points,
// and compares it to the team's output.

#include <vector>

typedef long double ld;
typedef std::vector<ld> vd;
typedef std::vector<vd> vvd;
typedef std::vector<vvd> vvvd;

const ld tolerance = 1e-6;

ld check_size(ld ax, ld ay, ld bx, ld by, ld cx, ld cy){
    return std::sqrt((ax-bx)*(ax-bx) + (ay-by)*(ay-by)) + std::sqrt((ax-cx)*(ax-cx) + (ay-cy)*(ay-cy)) + std::sqrt((bx-cx)*(bx-cx) + (by-cy)*(by-cy));
}

ld correct_answer(vd X, vd Y){
    // determine block size
    int block_num = std::max(3.,std::sqrt(X.size()/3.));
    ld block_width = (ld) 2000.00002/block_num;

    // place all points into the correct grid square
    vvvd gridX(block_num, vvd(block_num));
    vvvd gridY(block_num, vvd(block_num));

    for (int i=0; i<X.size(); i++){
        // indexes in the grid
        int tmpX = (X[i]+1000.00001)/block_width;
        int tmpY = (Y[i]+1000.00001)/block_width;

        gridX[tmpX][tmpY].push_back(X[i]);
        gridY[tmpX][tmpY].push_back(Y[i]);
    }

    // iterate over all 3x3 blocks

    ld lowest = 8000;
    for (int i=0; i<block_num-2; i++){
        for (int j=0; j<block_num-2; j++){
            // create vector with elements of 3x3 block
            vd tmpX;
            vd tmpY;
            for (int k=i; k<i+3; k++){
                for (int l=j; l<j+3; l++){
                    tmpX.insert(tmpX.end(), gridX[k][l].begin(), gridX[k][l].end());
                    tmpY.insert(tmpY.end(), gridY[k][l].begin(), gridY[k][l].end());
                }
            }

            // iterate over elements in 3x3 block
            if (tmpX.size()<3) continue;

            for (int a=0; a<tmpX.size()-2; a++){
                for (int b=a+1; b<tmpX.size()-1; b++){
                    for (int c=b+1; c<tmpX.size(); c++){
                        lowest = std::min(lowest, check_size(tmpX[a], tmpY[a], tmpX[b], tmpY[b], tmpX[c], tmpY[c]));
                    }
                }
            }
        }
    }

    return lowest;
}


int main(int argc, char **argv) {
    // The below part is copied from lowest latency from BAPC 2022

    std::ifstream in(argv[1]);

	int n, testcase_seed, fixed_seed;
	in >> n >> testcase_seed;

	// Generate the team seed.
	// True random purpose, needs to be random every time
	std::random_device dev; // bt ignore
	auto random_seed = dev();

	auto seed = testcase_seed ^ random_seed;

	if(in >> fixed_seed) {
		seed = fixed_seed;
	}

	std::cerr << "Seed: " << seed << std::endl;

	// Generate the team input.

    Generator g(seed);

    g.read_integer("n", n, n);
    g.newline();

    vd X(n),Y(n);

    for (int i=0; i<n; i++){
        X[i] = g.read_float("x", -1000., 1000.);
        g.space();
        Y[i] = g.read_float("y", -1000., 1000.);
        g.newline();
    }

    // Validate the team output

    ld intended_answer = correct_answer(X,Y);
    std::cerr << "Validator answer: " << std::setprecision(10) << intended_answer << std::endl;

    ld min_abs_ans = intended_answer - tolerance;
    ld max_abs_ans = intended_answer + tolerance;
    ld min_rel_ans = intended_answer * (1 - tolerance);
    ld max_rel_ans = intended_answer * (1 + tolerance);
    ld min_ans = std::min(min_abs_ans, min_rel_ans);
    ld max_ans = std::max(max_abs_ans, max_rel_ans);

    OutputValidator v(argc, argv);
	ld ans = v.read_float("ans", min_ans, max_ans);
	v.newline();
}
