import kotlin.math.sqrt

/**
 * I avoided this problem since it seem the dyslexia unfriendly one. But after giving it some thought its more a math
 * problem then a letter problem if you ask yourself what is the most compact way to write the most number of palindromes.
 *
 * Observation: The most compact way to write palindromes in by just using the same letter together. Such a string
 * contains (s+1)s/2 palindromes. (1 of size s, 2 of size s-1, ...,  s of size 1)
 *
 * Observation: The sqrt(2*10^9) fits in 10^5
 *
 * Fill the string with the first char, the fill the remainder with the next char, continue until you are at zero.
 *
 * Pitfall: the letters go out of 'a'-'z' range for high inputs if you go by a half to slow.
 *
 * Pitfall: If you don't use sqrt(2*s), but just sqrt(s) you answer will be `slightly` to long
 *
 * Pitfall: Using static string operations will be to slow.
 *
 */
fun main() {
    val s = readln().toInt()
    val result = StringBuilder()
    fun Char.next() = when (val n = this + 1) {
        in 'a'..'z' -> n
        else -> 'a'
    }

    tailrec fun append(s: Int, char: Char) {
        when (s) {
            0 -> return
            1 -> result.append(char)
            2 -> result.append(char).append(char.next())
            3 -> result.append(char).append(char)
            else -> {
                val k = sqrt(2.0 * s).toInt() - 1 // without minus 1 i sometimes get a negative remainder :/
                val remainder = s - (k * (k + 1) / 2)
                repeat(k) { result.append(char) }
                append(remainder, char.next())
            }
        }
    }
    append(s, 'a')
    println(result)
//    System.err.println("String is valid: ${result.all { it in 'a'..'z' }}")
//    System.err.println("Size of string: ${result.length}")
//    System.err.println("String contains: ${result.calculatePalindromes()}")
}

fun CharSequence.calculatePalindromes() =
    // really slow, but just for checking
    (1..length).sumOf { window ->
        windowed(window).count { it.isPalindrome() }
    }

fun CharSequence.isPalindrome() =
    take(length / 2).zip(reversed().take(length / 2)).all { (a, b) -> a == b }

