import java.util.PriorityQueue

/**
 * Problem is quite easy. Alternating between the highest frequency and lowest frequency. The random output is actually
 * a red haring, we just want an ordering that doesn't consist have the same artist in line. Since a valid solution is
 * guaranteed, ordering is actually the easiest way to do this.
 *
 * Pitfall: don't read from start and bottom, because you can get the same artist at the end. so order by size and take
 * the first two of the items to ensure the next artist is distinct from the previous.
 *
 * Problem description can be improved, the second alinea is independent of the story. I would
 * rewrite it so the text becomes part of the story.
 */

fun main() {
  val queue = System.`in`.bufferedReader().lineSequence().drop(1).map {
    it.split(" ").take(2).let { (a, b) -> a to b }
  }.groupBy({ it.first }) { it.second }.values.map { it.toMutableList() }
    .toCollection(PriorityQueue { a, b -> b.size.compareTo(a.size) })

  val result = StringBuilder()
  var next = queue.poll() // keep the next out of the queue, so the next artist is distinct
  var current: MutableList<String>
  while (queue.isNotEmpty()) {
    current = next
    next = queue.poll()
    result.append(current.removeLast()).append('\n')
    if(current.isNotEmpty()) queue.add(current)
  }
  result.append(next.first())
  println(result)
}
