import java.io.*;
import java.util.*;


public class VerwoerdScanner {
    public static void main(String[] args) throws IOException {
        var input = new Scanner(new BufferedReader(new InputStreamReader(System.in)));
        var n = input.nextInt();
        var m = input.nextInt();
        var tree = new SegmentTree(n);
        for (int i = 0; i < m; i++) {
            var w = input.nextInt();
            var l = input.nextInt();
            if (w < l) tree.update(w + 1, l, 1);
            else if (w > l) {
                tree.update(1, l, 1);
                tree.update(w + 1, n, 1);
            }
        }
        System.out.println(tree.query(1, n));
    }

    static class SegmentTree {
        private final SegementTreeNodeJava root;

        public SegmentTree(int size) {
            root = new SegementTreeNodeJava(1, size);
        }

        public void update(int rangeLo, int rangeHi, int value) {
            update(rangeLo, rangeHi, value, root);
        }

        public int query(int rangeLo, int rangeHi) {
            return query(rangeLo, rangeHi, root);
        }

        private void update(int rangeLo, int rangeHi, int value, SegementTreeNodeJava node) {
            if (node == null) return;
            if (rangeLo <= node.lo && node.hi <= rangeHi) {
                node.lazy += value;
            }

            pushDown(node);

            if (rangeLo <= node.lo && node.hi <= rangeHi || rangeHi < node.lo || rangeLo > node.hi) return;


            update(rangeLo, rangeHi, value, node.left);
            update(rangeLo, rangeHi, value, node.right);

            node.value = Math.min(node.left.value, node.right.value);
        }

        private void pushDown(SegementTreeNodeJava node) {
            node.value = node.value + node.lazy;

            if (node.lo != node.hi) {
                var mid = node.lo + (node.hi - node.lo) / 2;

                if (node.left == null) {
                    node.left = new SegementTreeNodeJava(node.lo, mid);
                }

                if (node.right == null) {
                    node.right = new SegementTreeNodeJava(mid + 1, node.hi);
                }

                node.left.lazy = node.left.lazy + node.lazy;
                node.right.lazy = node.right.lazy + node.lazy;
            }

            node.lazy = 0;
        }

        public int query(int rangeLo, int rangeHi, SegementTreeNodeJava node) {
            if (node == null) return Integer.MAX_VALUE;
            pushDown(node);

            // no overlap
            if (rangeLo > node.hi || rangeHi < node.lo) return Integer.MAX_VALUE;

            // complete overlap
            if (rangeLo <= node.lo && node.hi <= rangeHi) return node.value;

            var leftMax = query(rangeLo, rangeHi, node.left);
            var rightMax = query(rangeLo, rangeHi, node.right);

            return Math.min(leftMax, rightMax);
        }

        static class SegementTreeNodeJava {

            SegementTreeNodeJava(int low, int high) {
                lo = low;
                hi = high;
            }

            int lo;
            int hi;
            int value = 0;
            int lazy = 0;
            SegementTreeNodeJava left = null;
            SegementTreeNodeJava right = null;
        }
    }


}
