#include <iostream>
#include <string>
#include <vector>
#include <utility>

const int MAX_N = 2000;

std::string grid[MAX_N];

struct Cell {
  int next[4];
  bool taken_out;
} cells[MAX_N][MAX_N];

int charToInt(char chr) {
  switch(chr) {
    case '<': return 0;
    case '^': return 1;
    case '>': return 2;
    case 'v': return 3;
  }
  
  return -1;
}

int dl[4] = {0, -1, 0, 1};
int dc[4] = {-1, 0, 1, 0};

std::vector<std::pair<int, int> > solution;

void eliminate_list(int l, int c, int dir) {
  int ln = l + dl[dir] * cells[l][c].next[dir];
  int cn = c + dc[dir] * cells[l][c].next[dir];

  if (cells[ln][cn].next[dir] == 0)
    cells[l][c].next[dir] = 0;
  else
    cells[l][c].next[dir] += cells[ln][cn].next[dir];
}

void take_out(int l, int c) {
  int pointed_dir = charToInt(grid[l][c]);
  if (cells[l][c].taken_out)
    return ;
  if (cells[l][c].next[pointed_dir] != 0)
    return ;
  
  cells[l][c].taken_out = true;
  solution.push_back({l, c});

  for (int d = 0; d < 4; ++d) {
    int opposite = d ^ 2;

    if (cells[l][c].next[d] != 0)
      eliminate_list(l + dl[d] * cells[l][c].next[d], c + dc[d] * cells[l][c].next[d], opposite);
  }

  for (int d = 0; d < 4; ++d) {
    if (cells[l][c].next[d] != 0) {
      int ln = l + dl[d] * cells[l][c].next[d];
      int cn = c + dc[d] * cells[l][c].next[d];
      take_out(ln, cn);
    }
  }
}

int main() {
  std::ios_base::sync_with_stdio(false);
  std::cin.tie(NULL);

  int n, m;
  std::cin >> n >> m;
  for (int i = 0; i < n; ++i)
    std::cin >> grid[i];

  for (int l = 0; l < n; ++l)
    for (int c = 0; c < m; ++c)
      for (int d = 0; d < 4; ++d) {
        int ln = l + dl[d];
        int cn = c + dc[d];

        if (0 <= ln && ln < n && 0 <= cn && cn < m)
          cells[l][c].next[d] = 1;
      }

  for (int l = 0; l < n; ++l)
    for (int c = 0; c < m; ++c)
      if (!cells[l][c].taken_out) {
        take_out(l, c);        
      }

  if (solution.size() == (unsigned int)n * m) {
    for (auto it: solution)
      std::cout << it.first + 1 << " " << it.second + 1 << "\n";
  } else
    std::cout << "impossible\n";

  return 0;
}

