#include <iostream>
#include <string>
#include <vector>
#include <utility>
#include <queue>
#include <cassert>

const int MAX_N = 2000;

std::string matr[MAX_N];

std::pair<int, int> last_cell[4][MAX_N];
bool in_queue[4][MAX_N];

//          >  v  <   ^
int dl[] = {0, 1, 0, -1};
int dc[] = {1, 0,-1,  0};

bool taken_out[MAX_N][MAX_N];

std::vector<std::pair<int, int>> solution;

int charToDir(char chr) {
  switch (chr) {
    case '>': return 0;
    case 'v': return 1;
    case '<': return 2;
    case '^': return 3;
  }

  return -1;
}

static inline int opposite(int dir) {
  return dir ^ 2;
}

void try_push(int dir, int coord, std::queue<std::pair<int, int> >& queue) {
  if (!in_queue[dir][coord]) {
    in_queue[dir][coord] = true;
    queue.push({dir, coord});
  }
}

void solve_grid(int n, int m, std::queue<std::pair<int, int> >& queue) {
  while (!queue.empty()) {
    int dir = queue.front().first;
    int coord = queue.front().second;
    queue.pop();
    in_queue[dir][coord] = false;

    int l = last_cell[dir][coord].first;
    int c = last_cell[dir][coord].second;

    while (0 <= l && l < n && 0 <= c && c < m && taken_out[l][c]) {
      l = l + dl[opposite(dir)];
      c = c + dc[opposite(dir)];
      last_cell[dir][coord] = {l, c};
    }

    if (0 <= l && l < n && 0 <= c && c < m &&
        charToDir(matr[l][c]) == dir) {
      taken_out[l][c] = true;
      solution.push_back({l, c});

      try_push(0, l, queue);
      try_push(2, l, queue);
      try_push(1, c, queue);
      try_push(3, c, queue);
    }
  }
}

int main() {
  std::ios_base::sync_with_stdio(false);
  std::cin.tie(NULL);

  int n, m;

  std::cin >> n >> m;

  for (int i = 0; i < n; ++i)
    std::cin >> matr[i];

  std::queue<std::pair<int, int> > queue;

  for (int i = 0; i < n; ++i) {
    last_cell[0][i] = {i, m - 1};
    last_cell[2][i] = {i, 0};
    
    queue.push({0, i});
    queue.push({2, i});
  }

  for (int i = 0; i < m; ++i) {
    last_cell[1][i] = {n - 1, i};
    last_cell[3][i] = {0, i};
    
    queue.push({1, i});
    queue.push({3, i});
  }

  solve_grid(n, m, queue);

  if ((int)solution.size() < n * m)
    std::cout << "impossible\n";
  else {
    for (auto it: solution)
      std::cout << it.first + 1 << " " << it.second + 1 << "\n";
  }

  return 0;
}

