// @EXPECTED_RESULTS@: TIME_LIMIT_EXCEEDED, WRONG_ANSWER
import kotlin.math.pow
import kotlin.math.sqrt

/**
 * Uses the k closest point approach to a given target. For every point, we use calculate the 2 closest points by euclidian distance.
 * By only looking at the points not already visited.
 * Then we determine for each triple the perimeter.
 *
 * This should be O(n log n)
 */
fun main() {
    val n = readln().toInt()
    val points = System.`in`.bufferedReader().lineSequence().take(n).map { l ->
        l.split(" ").map { it.toDouble() }.let { (x, y) -> x to y }
    }.toList().toTypedArray()
    (0..n - 3).minOf { index ->
        val c = points[index]
        val (a, b) = c.twoClosest(points, index + 1)
        calculatePerimeter(c, a, b)
    }.let { println(it) }
}

fun Point.twoClosest(list: Array<Point>, start: Int): Pair<Point, Point> {
    var min1 = Double.MAX_VALUE
    var min1Point: Point = -1000.0 to -1000.0
    var min2 = Double.MAX_VALUE
    var min2Point: Point = 1000.0 to 1000.0
    // since we only need 2 points, no need to sort, we can just loop over it once
    (start until list.size).forEach {
        val point = list[it]
        val distance = calculateDistance(this, point)
        if (distance < min1) {
            min2Point = min1Point
            min1 = distance
            min1Point = point
        } else if (distance < min2) {
            min2Point = point
            min2 = distance
        }
    }
    return min1Point to min2Point
}


typealias Point = Pair<Double, Double>

fun Point.x() = first
fun Point.y() = second

val cacheMap = mutableMapOf<Triple<Point, Point, Point>, Double>()
val lineMap = mutableMapOf<Pair<Point, Point>, Double>()
fun calculateDistance(a: Point, b: Point) =
    lineMap.computeIfAbsent(a to b) { (a, b) -> sqrt((a.x() - b.x()).pow(2) + (a.y() - b.y()).pow(2)) }

fun calculatePerimeter(a: Point, b: Point, c: Point) = cacheMap.computeIfAbsent(Triple(a, b, c)) { (a, b, c) ->
    calculateDistance(a, b) + calculateDistance(b, c) + calculateDistance(c, a)
}
