// @EXPECTED_RESULTS@: TIME_LIMIT_EXCEEDED, WRONG_ANSWER
import java.util.LinkedList

/**
 * Fun geometry puzzle. Seems like a mostly just do it.
 *
 * I fluf my grid with an additional border to fix both the coordinates and keep track of the open moves. The initial
 * open moves are only on the border of the original grid. Every time you remove a block, new blocks might be found
 * that can be removed adjacent to the tile being removed. Keep going until no more valid moves are possible.
 *
 * Please consider removing the last line of problem description, this is already said in the input/output statement or
 * describe it in the context of the story. Stop breaking the fourth wall XD.
 */
fun main() {
  val (h, w) = readln().split(" ").map { it.toInt() }
  val border = CharArray(w + 2) { '0' }
  val grid = listOf(border) + System.`in`.bufferedReader().lineSequence().map {
    "0${it}0".toCharArray()
  }.toList() + listOf(border)

  fun Coordinate.isRemovable(): Boolean {
    val current = grid[this]
    return current != '0' && grid[this.needsFree(current)] == '0'
  }

  val openMoves = LinkedList<Coordinate>()
  val seen = BooleanArray((h+1)*(w+1))
  fun offer(coordinate: Coordinate) {
    if(!seen[coordinate.getIndex(w)]) {
      seen[coordinate.getIndex(w)] = true
      openMoves.add(coordinate)
    }

  }

  repeat(w) { x ->
    Coordinate(1, x + 1).takeIf { it.isRemovable() }?.also { offer(it) }
    Coordinate(h, x + 1).takeIf { it.isRemovable() }?.also { offer(it) }
  }
  repeat(h-2) { y ->
    Coordinate(y + 2, 1).takeIf { it.isRemovable() }?.also { offer(it) }
    Coordinate(y + 2, w).takeIf { it.isRemovable() }?.also { offer(it) }
  }
  val moves = mutableListOf<Coordinate>()
  while (openMoves.isNotEmpty()) {
    val current = openMoves.poll()
    moves.add(current)
    grid[current] = '0'
    current.findNeighbours().filter { it.isRemovable() }.forEach { offer(it) }
  }
  if (moves.size < h * w) println("impossible")
  else moves.forEach { println(it) }
}

operator fun List<CharArray>.get(c: Coordinate) = get(c.y)[c.x]

operator fun List<CharArray>.set(c: Coordinate, value: Char): Unit {
  get(c.y)[c.x] = value
}

data class Coordinate(val y: Int, val x: Int){
  override fun toString() = "$y $x"

  operator fun plus(other: Coordinate) = Coordinate(y + other.y, x + other.x)

  fun findNeighbours() = sequenceOf(
    this + Coordinate(-1, 0), this + Coordinate(0, -1), this + Coordinate(1, 0), this + Coordinate(0, 1)
                                   )

  fun needsFree(c: Char) = when (c) {
    '^' -> this + Coordinate(-1, 0)
    '<' -> this + Coordinate(0, -1)
    'v' -> this + Coordinate(1, 0)
    '>' -> this + Coordinate(0, 1)
    else -> error("Invalid input found square $c")
  }

  fun getIndex(maxWidth: Int) = y*maxWidth + x
}
