/**
 * Solid problem traditional problem. This is a variation of the painters partition problem. This can be solved using
 * DP and gives a time complexity of O(kn^3) and O(kn^2) with preprocessing.
 */
fun main() {
    val input = System.`in`.bufferedReader()
    val (n, k) = input.readLine().split(" ").map { it.toInt() }
    val boxes = input.readLine().split(" ").map { it.toLong() }
    println(boxes.findMax(n, k))
}

// bottom up tabular dp
fun List<Long>.findMax(n: Int, k: Int): Long {
    // initialize table
    val dp = Array(k + 1) { LongArray(n + 1) }
    // create cumulative sum table to avoid having to loop ove the list for every minOf operation
    val sum = LongArray(n + 1)
    (1..n).forEach { sum[it] = sum[it - 1] + get(it - 1) }

    // base cases
    // only one divider -> cumulative sum
    (1..n).forEach { dp[1][it] = sum[it] }

    // set of size 1 -> the first value
    val start = first()
    for (i in 1..k) dp[i][1] = start
    // 2 to k partitions
    (2..k).forEach { i ->
        (2..n).forEach { j ->
            // find the largest segment with a set of size j and i dividers.
            // the following tries to place the divider on place i, the then calculates what the largest
            // group is and the minimum value is added to the DP table
            // adding to p then the largets group is max(dp[i-1][p], boxes.sublist(j, p).sum())
            // So the new element is added to the last segment.
            dp[i][j] = (1 until j).minOf { p -> dp[i - 1][p].coerceAtLeast(sum[j] - sum[p]) }
        }
    }
    return dp[k][n]
}
