import java.util.LinkedList

/**
 * Problem G with preprocessing. For each node we mark the coordinates for each column of row the dependents and keep a
 * list with the number of dependencies. Tiles with 0 dependencies will be added to the queue. Every time a tile is removed
 * we check all dependents of the tile and reduce the dependents. Once all dependents are removed, we add those to the queue.
 *
 * This should have a time complexity of O(hw^2)
 */

fun main() {
    val (h, w) = readln().split(" ").map { it.toInt() }
    val dependencies = mutableMapOf<Coordinate, MutableList<Coordinate>>()
    val dependencyMap = mutableMapOf<Coordinate, Int>()

    // create a map for each tile which tile needs to be removed first
    val grid = System.`in`.bufferedReader().lineSequence().withIndex().map { (y, value) ->
        value.mapIndexed { x, c ->
            val coordinate = Coordinate(y + 1, x + 1)
            when (c) {
                '^' -> {
                    dependencyMap[coordinate] = y
                    (1..y).forEach { dependencies.getOrPut(Coordinate(it, x + 1), ::mutableListOf).add(coordinate) }
                }

                'v' -> {
                    dependencyMap[coordinate] = h - y - 1
                    (y + 2..h).forEach { dependencies.getOrPut(Coordinate(it, x + 1), ::mutableListOf).add(coordinate) }
                }

                '<' -> {
                    dependencyMap[coordinate] = x
                    (1..x).forEach { dependencies.getOrPut(Coordinate(y + 1, it), ::mutableListOf).add(coordinate) }
                }

                '>' -> {
                    dependencyMap[coordinate] = w - x - 1
                    (x + 2..w).forEach { dependencies.getOrPut(Coordinate(y + 1, it), ::mutableListOf).add(coordinate) }
                }

                else -> error("Invalid input")
            }
            coordinate
        }
    }.toList()

    val queue = dependencyMap.filter { it.value == 0 }.map { it.key }.toCollection(LinkedList())
    val moves = LinkedList<Coordinate>()
    while (queue.isNotEmpty()) {
        val current = queue.removeFirst()
        moves.add(current)
        dependencies[current]?.forEach {
            val value = dependencyMap[it]!!
            if (value == 1) {
                queue.add(it)
            }
            dependencyMap[it] = value - 1
        }
    }
    if (moves.size < h * w) println("impossible")
    else moves.forEach { println(it) }
}

data class Coordinate(val y: Int, val x: Int) {
    override fun toString() = "$y $x"

    operator fun plus(other: Coordinate) = Coordinate(y + other.y, x + other.x)

    fun findNeighbours() = sequenceOf(
        '^' to this + Coordinate(-1, 0),
        'v' to this + Coordinate(0, -1),
        '<' to this + Coordinate(1, 0),
        '>' to this + Coordinate(0, 1)
    )

    fun getIndex(maxWidth: Int) = y * maxWidth + x
}
