import kotlin.math.abs
import kotlin.math.pow
import kotlin.math.sqrt

/**
 * Given n in [3, 10_000] uniform random points in (-1000, 1000) find the smallest perimeter of 3 points
 * We are going to abuse the Mean line segement length since points are uniform random distributred in a square
 * The average distance between 2 points is ~52.1405% of 2000 = C (https://en.wikipedia.org/wiki/Mean_line_segment_length#Square_and_rectangles)
 * So the average perimiter should be ~3128.43
 * The average distance between to points 1/3C = WINDOW (https://en.wikipedia.org/wiki/Mean_line_segment_length#Line_segment)
 */
const val C = 1042.81
const val WINDOW = C / 3
fun main() {
    val n = readln().toInt()
    val points = System.`in`.bufferedReader().lineSequence().take(n).map { l ->
        l.split(" ").map { it.toDouble() }.let { (x, y) -> x+1000 to y+1000 }
    }.toList()
    var min = Double.MAX_VALUE
    if (n == 3) {
        return println(points.let { (a, b, c) -> calculatePerimeter(a, b, c) })
    } else if (n < 128) { // lalala bruteforce, when TLE lower number
        points.dropLast(2).withIndex().forEach {(i,a)  ->
            points.drop(i+1).dropLast(1).withIndex().forEach { (j,b) ->
                points.drop(i+j+2).forEach { c ->
//                    System.err.println("$a, $b, $c, ${calculatePerimeter(a,b,c)}")
                    min = min.coerceAtMost(calculatePerimeter(a,b,c))
                }
            }
        }
        return println(min)
    }
    // take advantage of rand distributed
    // sort by x
    val xlist = points.sortedBy { it.x() }

    xlist.withIndex().forEach { (index, c) ->
        val selected = xlist.drop(index + 1).takeWhile { it.x() - c.x() < 2 * WINDOW }
//        System.err.println("[$c] Choose $selected points")
        selected.withIndex().filter { it.index < selected.size - 1 }.forEach { (index, d) ->
            min = min.coerceAtMost(selected.drop(index + 1).minOfOrNull {
//                System.err.println("Got $c, $d, $it, ${calculatePerimeter(c, d, it)}")
                calculatePerimeter(c, d, it)
            } ?: Double.MAX_VALUE)
//            System.err.println(min)
        }
    }
    println(min)
}


typealias Point = Pair<Double, Double>

fun Point.x() = first
fun Point.y() = second

val cacheMap = mutableMapOf<Triple<Point, Point, Point>, Double>()
val lineMap = mutableMapOf<Pair<Point, Point>, Double>()
fun calculateDistance(a:Point, b: Point) = lineMap.computeIfAbsent(a to b) {(a,b) ->sqrt((a.x() - b.x()).pow(2) + (a.y() - b.y()).pow(2))}

fun calculatePerimeter(a: Point, b: Point, c: Point) = cacheMap.computeIfAbsent(Triple(a, b, c)) { (a, b, c) ->
    calculateDistance(a,b) + calculateDistance(b,c) + calculateDistance(c, a)
}
