/**
 * Observations: for every side you always have to update from a single side.
 *
 * Approach:
 * Keep 4 arrays for each direction.
 * Check for every direction if you can remove the closest tile still in play in that appropriate direction.
 * Skip over already removed tiles. Keep looping until you have no more changes.
 */

fun main() {
  val (h, w) = readln().split(" ").map { it.toInt() }
  val grid = System.`in`.bufferedReader().lineSequence().map {
    it.toCharArray()
  }.toList()
  val topRow = IntArray(w) { 0 }
  val bottomRow = IntArray(w) { h - 1 }
  val leftColumn = IntArray(h) { 0 }
  val rightColum = IntArray(h) { w - 1}
  val seen = Array(h) { BooleanArray(w) }
  var updates = 0
  var total = 0
  val result = StringBuilder()
  fun register(x: Int, y: Int) {
    result.append(y + 1).append(" ").append(x + 1).append("\n")
    seen[y][x] = true
    updates++
  }
  var iterations = 0
  do {
    iterations++
    total += updates
    updates = 0
    // check left column '<'
    leftColumn.forEachIndexed { y, xTmp ->
      if (xTmp < w) {
        var x = xTmp
        // forward to the first not seen grid tile
        while (x < w && seen[y][x]) {
          x++
        }
        if (x < w && grid[y][x] == '<') {
          // this tile can be removed
          register(x, y)
          leftColumn[y] = x + 1
        } else if (x != xTmp) {
          leftColumn[y] = x
        }
      }
    }
    // check top row for '^'
    topRow.forEachIndexed { x, yTmp ->
      if (yTmp < h) {
        var y = yTmp
        // forward to the first not seen grid tile
        while (y < h && seen[y][x]) {
          y++
        }
        if (y < h && grid[y][x] == '^') {
          // this tile can be removed
          register(x, y)
          topRow[x] = y + 1
        } else if (y != yTmp) {
          topRow[x] = y
        }
      }
    }
    // check top right colums for '>'
    rightColum.forEachIndexed { y, xTmp ->
      if (xTmp >= 0) {
        var x = xTmp
        // forward to the first not seen grid tile
        while (x >= 0 && seen[y][x]) {
          x--
        }
        if (x >= 0 && grid[y][x] == '>') {
          // this tile can be removed
          register(x, y)
          rightColum[y] = x - 1
        } else if (x != xTmp) {
          rightColum[y] = x
        }
      }
    }
    // check bottom row for 'v'
    bottomRow.forEachIndexed { x, yTmp ->
      if (yTmp>=0) {
        var y = yTmp
        // forward to the first not seen grid tile
        while (y >= 0  && seen[y][x]) {
          y--
        }
        if (y>=0 && grid[y][x] == 'v') {
          // this tile can be removed
          register(x, y)
          bottomRow[x] = y - 1
        } else if (y != yTmp) {
          bottomRow[x] = y
        }
      }
    }
  } while (updates > 0)
//  println("$iterations $total $updates")
  if(total < h*w) println("impossible")
  else print(result)
}
