import kotlin.math.min
import kotlin.math.pow
import kotlin.math.sqrt

/**
 * Since the problem states uniformly random distribution , this means something has to be done with it.
 *
 * First example is not uniformly random distributed
 *
 * Observation: average distance between 2 points  is sqrt(2000^2/n) on average
 * Observation: the smallest enclosed area is always a triangle
 * Observation: If another pole is in the triangle, this will give always a smaller triangle
 *
 * Approach 1: create 4 triangles with the 4 extreme points, divide each triangle to each 3 new triangles around the point (stop, this going exponential)
 *
 * Approach 2: sort points on x. match with the point to the right. search for a point with average distance of the
 * initial points. Calculate the area and rinse and repeat, min all found areas.
 *
 * Approach 3: Wait, what if we just zip with the 3 closest points, the minimum has to be one of those, right?
 *
 * Note to self: Perimeter != area.
 */
fun main() {
    val n = readln().toInt()
    val points = System.`in`.bufferedReader().lineSequence().take(n).map { l ->
        l.split(" ").map { it.toDouble() }.let { (x, y) -> x to y }
    }.toList()
    val xlist = points.sortedBy { it.x() }
    val ylist = points.sortedBy { it.y() }
    println(

        xlist.windowed(size = 3, step = 1, partialWindows = false)
            .minOf { (a, b, c) -> calculatePerimeter(a, b, c) }
            .coerceAtMost(
                ylist.windowed(3, 1).minOf { (a, b, c) -> calculatePerimeter(a, b, c) }
            )
    )
}

typealias Point = Pair<Double, Double>

fun Point.x() = first
fun Point.y() = second

fun calculatePerimeter(a: Point, b: Point, c: Point) =
    sqrt((a.x() - b.x()).pow(2) + (a.y() - b.y()).pow(2)) + sqrt((b.x() - c.x()).pow(2) + (b.y() - c.y()).pow(2)) +
            sqrt((c.x() - a.x()).pow(2) + (c.y() - a.y()).pow(2))

