/*
Problem difficulty: 4 stars out of 5 stars

This problem is requests a complex implementation and also mathematical formulas.
The informations needed for this problem  are: euclidean distance and the perimeter of a triangle.

The first step of solving this problem is that the perimeter of the smallest possible proper enclosure is obtained only when we can form a triangle.
Since we cannot calculate the perimeter of each possible triangle we will have to retain all the coordinates of a fencepost in 2 arrays. The first array is going to be sorted depending on the x-axis and the other on the y-axis. Right now we will have to calculate the smallest possible perimeter of the triangle the we can obtain:


Let's say that we picked the point P(x,y). The point P has index i in the first sorted array and index j in the second array. We will calculatethe minimum between Perimeter of the triangles with points:
(P,Pi-1,Pj-1),(P,Pi-1,Pj+1),(P,Pi+1,Pj-1),(P,Pi+1,Pj+1).

Complexity of the problem: O(nlogn)
*/

#include <iostream>
#include <algorithm>
#include <vector>
#include <cmath>
#include <map>
#include <iomanip>

using namespace std;

const int NMAX=1e4+5;
const int INF=-2e9;

struct coords{
    long double x;
    long double y;
}v1[NMAX],v2[NMAX],v[NMAX];

bool cmp1(coords a,coords b)
{
    if(a.x==b.x)
        return a.y<b.y;
    return a.x<b.x;
}

bool cmp2(coords a,coords b)
{
    if(a.y==b.y)
        return a.x<b.x;
    return a.y<b.y;
}

long double dista_euclid(coords a,coords b)
{
    long double dist=(long double)sqrt((long double)(a.x-b.x)*(a.x-b.x)+(a.y-b.y)*(a.y-b.y));
    return (long double)sqrt((double)((a.x-b.x)*(a.x-b.x)+(a.y-b.y)*(a.y-b.y)));
}

long double solve_perimeter(coords a,coords b,coords c)
{
    long double peri;
    peri=dista_euclid(a,b)+dista_euclid(b,c)+dista_euclid(a,c);
    return peri;
}

map<pair<long double,long double>,coords>mp[5];
/*
    1->next on x-axis;
    2->previous on x-axis;
    3->next on y-axis;
    4->previous on y-axis;
*/

int main()
{
    int n,i,j;
    long double mini=-INF;
    cin>>n;
    for(i=1;i<=n;i++)
    {
        cin>>v[i].x>>v[i].y;
        v1[i].x=v2[i].x=v[i].x;
        v1[i].y=v2[i].y=v[i].y;
        mp[1][make_pair(v[i].x,v[i].y)].x=mp[1][make_pair(v[i].x,v[i].y)].y=-INF;
        mp[2][make_pair(v[i].x,v[i].y)].x=mp[2][make_pair(v[i].x,v[i].y)].y=-INF;
        mp[3][make_pair(v[i].x,v[i].y)].x=mp[3][make_pair(v[i].x,v[i].y)].y=-INF;
        mp[4][make_pair(v[i].x,v[i].y)].x=mp[4][make_pair(v[i].x,v[i].y)].y=-INF;
    }
    sort(v1+1,v1+n+1,cmp1);
    sort(v2+1,v2+n+1,cmp2);
    for(i=1;i<=n;i++)
    {
        if(i!=1)
        {
            mp[2][make_pair(v1[i].x,v1[i].y)]=v1[i-1];
            mp[4][make_pair(v2[i].x,v2[i].y)]=v2[i-1];
        }
        if(i!=n)
        {
            mp[1][make_pair(v1[i].x,v1[i].y)]=v1[i+1];
            mp[3][make_pair(v2[i].x,v2[i].y)]=v2[i+1];
        }
    }
    for(i=1;i<=n;i++)
    {
            if(mp[1][make_pair(v[i].x,v[i].y)].x!=mp[2][make_pair(v[i].x,v[i].y)].x || mp[1][make_pair(v[i].x,v[i].y)].y!=mp[2][make_pair(v[i].x,v[i].y)].y)
                mini=min(mini,solve_perimeter(v[i],mp[1][make_pair(v[i].x,v[i].y)],mp[2][make_pair(v[i].x,v[i].y)]));
            if(mp[1][make_pair(v[i].x,v[i].y)].x!=mp[3][make_pair(v[i].x,v[i].y)].x || mp[1][make_pair(v[i].x,v[i].y)].y!=mp[3][make_pair(v[i].x,v[i].y)].y)
                mini=min(mini,solve_perimeter(v[i],mp[1][make_pair(v[i].x,v[i].y)],mp[3][make_pair(v[i].x,v[i].y)]));
            if(mp[1][make_pair(v[i].x,v[i].y)].x!=mp[4][make_pair(v[i].x,v[i].y)].x || mp[1][make_pair(v[i].x,v[i].y)].y!=mp[4][make_pair(v[i].x,v[i].y)].y)
                mini=min(mini,solve_perimeter(v[i],mp[1][make_pair(v[i].x,v[i].y)],mp[4][make_pair(v[i].x,v[i].y)]));
            if(mp[2][make_pair(v[i].x,v[i].y)].x!=mp[3][make_pair(v[i].x,v[i].y)].x || mp[2][make_pair(v[i].x,v[i].y)].y!=mp[3][make_pair(v[i].x,v[i].y)].y)
                mini=min(mini,solve_perimeter(v[i],mp[2][make_pair(v[i].x,v[i].y)],mp[3][make_pair(v[i].x,v[i].y)]));
            if(mp[2][make_pair(v[i].x,v[i].y)].x!=mp[4][make_pair(v[i].x,v[i].y)].x || mp[2][make_pair(v[i].x,v[i].y)].y!=mp[4][make_pair(v[i].x,v[i].y)].y)
                mini=min(mini,solve_perimeter(v[i],mp[2][make_pair(v[i].x,v[i].y)],mp[4][make_pair(v[i].x,v[i].y)]));
            if(mp[3][make_pair(v[i].x,v[i].y)].x!=mp[4][make_pair(v[i].x,v[i].y)].x || mp[3][make_pair(v[i].x,v[i].y)].y!=mp[4][make_pair(v[i].x,v[i].y)].y)
                mini=min(mini,solve_perimeter(v[i],mp[3][make_pair(v[i].x,v[i].y)],mp[4][make_pair(v[i].x,v[i].y)]));
    }
    cout<<fixed<<setprecision(6)<<mini;
    return 0;
}
